@@ -61,6 +61,7 @@ class ModUserState(Cmd):
         self.cmd = PYMUMBLE_CMD_MODUSERSTATE
         self.parameters = params
 
+
 class RemoveUser(Cmd):
     """Command to kick (ban=False) or ban (ban=True) a user"""
 
@@ -70,6 +71,7 @@ class RemoveUser(Cmd):
         self.cmd = PYMUMBLE_CMD_REMOVEUSER
         self.parameters = params
 
+
 class CreateChannel(Cmd):
     """Command to create channel"""
 
@@ -92,6 +94,16 @@ class RemoveChannel(Cmd):
         self.parameters = {"channel_id": channel_id}
 
 
+class UpdateChannel(Cmd):
+    """Command to update channel"""
+
+    def __init__(self, params):
+        Cmd.__init__(self)
+
+        self.cmd = PYMUMBLE_CMD_UPDATECHANNEL
+        self.parameters = params
+
+
 class VoiceTarget(Cmd):
     """Command to create a whisper"""
 
@@ -102,15 +114,27 @@ class VoiceTarget(Cmd):
         self.parameters = {"id": voice_id,
                            "targets": targets}
 
+
+class LinkChannel(Cmd):
+    """Command to link channel"""
+
+    def __init__(self, params):
+        Cmd.__init__(self)
+
+        self.cmd = PYMUMBLE_CMD_LINKCHANNEL
+        self.parameters = params
+
+
 class UnlinkChannel(Cmd):
     """Command to unlink channel"""
 
     def __init__(self, params):
         Cmd.__init__(self)
 
-        self.cmd = PYMUMBLE_CMD_CHANNELUNLINK
+        self.cmd = PYMUMBLE_CMD_UNLINKCHANNEL
         self.parameters = params
 
+
 class QueryACL(Cmd):
     """Command to query ACL information for channel"""
 
@@ -119,3 +143,16 @@ class QueryACL(Cmd):
 
         self.cmd = PYMUMBLE_CMD_QUERYACL
         self.parameters = {"channel_id": channel_id}
+
+
+class UpdateACL(Cmd):
+    """Command to Update ACL information for channel"""
+
+    def __init__(self, channel_id, inherit_acls, chan_group, chan_acl):
+        Cmd.__init__(self)
+
+        self.cmd = PYMUMBLE_CMD_UPDATEACL
+        self.parameters = {"channel_id": channel_id,
+                           "inherit_acls": inherit_acls,
+                           "chan_group": chan_group,
+                           "chan_acl": chan_acl}
